@@ -15,6 +15,7 @@ from tqdm.contrib.logging import logging_redirect_tqdm
 from .antibodyregistry import AntibodyRegistryGetter
 from .bigg import BiGGGetter
 from .biogrid import BioGRIDGetter
+from .ccle import CCLEGetter
 from .cellosaurus import CellosaurusGetter
 from .chebi import ChEBIGetter
 from .chembl import ChEMBLGetter
@@ -86,6 +87,7 @@ __all__ = [
     "AntibodyRegistryGetter",
     "BiGGGetter",
     "BioGRIDGetter",
+    "CCLEGetter",
     "CellosaurusGetter",
     "ChEBIGetter",
     "ChEMBLGetter",
@@ -257,7 +259,7 @@ def iter_versions(
     """Iterate over versions, without caching."""
     with logging_redirect_tqdm():
         getters = tqdm(
-            getter_resolver, disable=not use_tqdm, desc="Getting versions", unit="resource"
+            list(getter_resolver), disable=not use_tqdm, desc="Getting versions", unit="resource"
         )
         for cls in getters:
             getters.set_postfix(name=cls.name)
