@@ -1,6 +1,8 @@
 """A getter for MeSH."""
 
+import datetime
 import ftplib
+import logging
 
 from bioversions.utils import Getter, VersionType
 
@@ -8,6 +10,8 @@ __all__ = [
     "MeshGetter",
 ]
 
+logger = logging.getLogger(__name__)
+
 #: In 2024 and before, these were .gz, but after
 #: became .xml files
 SUFFIXES = [".xml", ".xml.gz", ".gz"]
@@ -23,16 +27,24 @@ class MeshGetter(Getter):
 
     def get(self):
         """Get the latest MeSH version number."""
-        with ftplib.FTP("nlmpubs.nlm.nih.gov") as ftp:
-            ftp.login()
-            ftp.cwd("/online/mesh/MESH_FILES/xmlmesh/")
-            names = [name for name, _ in ftp.mlsd()]
+        try:
+            with ftplib.FTP("nlmpubs.nlm.nih.gov") as ftp:
+                ftp.login()
+                ftp.cwd("/online/mesh/MESH_FILES/xmlmesh/")
+                names = [name for name, _ in ftp.mlsd()]
+
+        except Exception as e:
+            logger.warning(
+                "could not look up MeSH version, falling back to current year. exception: %s", e
+            )
+            return str(datetime.date.today().year)
 
         for name in names:
             for suffix in SUFFIXES:
                 if name.startswith("desc") and name.endswith(suffix):
                     return name[len("desc") : -len(suffix)]
-        raise ValueError
+
+        raise ValueError("unable to parse results returned from MeSH FTP")
 
 
 if __name__ == "__main__":
